/************************************************************************************/
/*  Copyright (C)           Microcyber Inc. All Rights Reserved                     */
/*  Product:                NCS-PT105II Profibus PA                                 */
/*                                                                                  */
/*  Device:                 NCS-PT105II PRESSURE DEVICE for PROFIBUS PA             */
/*  Description:            Device Description File                                 */
/*  Dictionary:             SIPADC01.dct                                            */
/*                                                                                  */
/*  Revision:  1.0                                                                  */
/*  Date:      2008-05-19                                                           */
/*  Author:    Ning Dekui                                                           */
/************************************************************************************/
MANUFACTURER            0x16c,
DEVICE_TYPE             0x01,
DEVICE_REVISION         0x01,
DD_REVISION             0x01

#define DEVICE_TYPE "NCS_PT105"
#define _NCS_PT

#include "SI_FileM.inc"
#include "SI_HlpM.inc"
#include "SI_OptM.inc"
#include "SIPAST_CommError.inc"

/*
#include "SI_MainMenu.inc"
#include "SI_ViewM.inc"
*/

#include "defmacros.inc"
#include "Phys_Blk.inc"
#include "AI1_Blk1.inc"
#include "MC_YT.inc" 

/***********************************************************************/
/*    Transducer Block 1: Pressure                                     */
/***********************************************************************/

BLOCK transducer_block_1
{
    TYPE    TRANSDUCER;
    NUMBER    1;
}

trans1_blk_reserve                          LIKE VARIABLE    phys_blk_reserve
{
}

VARIABLE trans1_blk_object
{
    LABEL        [blk_block_object];
    HELP        [blk_block_object_help];
    CLASS        CONTAINED;
    TYPE        ENUMERATED(1)
    {
        {    3,    [blk_block_object_TRANSDUCER]        }
    }
    HANDLING    READ;
}

VARIABLE trans1_blk_parent_class
{
    LABEL        [blk_parent_class];
    HELP        [trans_blk_parent_class_help];
    CLASS        CONTAINED;
    TYPE        ENUMERATED(1)
    {
        {    1,    [trans_blk_parent_class_PRES]   }
    }
    HANDLING    READ;
}

VARIABLE trans1_blk_class
{
    LABEL        [blk_class];
    HELP        [trans_blk_class_help];
    CLASS        CONTAINED;
    TYPE        ENUMERATED(1)
    {
        SELECT( trans1_blk_parent_class )
        {
            CASE 1:
            {    1,        [trans_pres_blk_class_DIFF]            },
            {    2,        [trans_pres_blk_class_ABS]            },
            {    3,        [trans_pres_blk_class_GAGE]            },
            {    4,        "Pressure + Level + Flow"            },
            {    5,        "Pressure + Level"                    },
            {    6,        "Pressure + Flow"                    },
            {    7,        "Mixed absolute + diff.Pressure"    }

            CASE 2:
            {    1,        [trans_temp_blk_class_TC]            },
            {    2,        [trans_temp_blk_class_RTD]            },
            {    3,        [trans_temp_blk_class_PYR]            },
            {    16,        "TC + DC U"                            },
            {    17,        "RTD + R"                            },
            {    18,        "TC + RTD + R + DC U"                }

            CASE 3:
            {    1,        [trans_flow_blk_class_MAGNETIC]        },
            {    2,        [trans_flow_blk_class_VORTEX]        },
            {    3,        [trans_flow_blk_class_CORIOLIS]        },
            {    4,        [trans_flow_blk_class_THERMAL]        },
            {    5,        [trans_flow_blk_class_ULTRASONIC]    },
            {    6,        "Variable Area"                        },
            {    7,        "Differential Pressure"}
            
            CASE 4:
            {    1,        [trans_lev_blk_class_HYDRO]            },
            {    2,        [trans_lev_blk_class_ECHO]            },
            {    3,        "Radiometric"                        },
            {    4,        [trans_lev_blk_class_CAPACITIVE]    }

            CASE 5:
            {    1,        "Electric"                            },
            {    2,        "Electro-pneumatic"                    },
            {    3,        "Electro-hydraulic"                    }

            CASE 6:
            {    1,        [trans_DI_blk_class_IO]                },
            {    2,        "Actuator"                            }

            CASE 7:
            {    1,        [standard]                            }

            CASE 8:
            {    1,        "Transfer"                            },
            {    2,        "Control"                            },
            {    3,        "Limit"                                }

            CASE 9:
            {    1,        "Binary Message"                    }

            DEFAULT:
            {    1,        [standard]                    }
        }
        {    250,    [not_used]                     },
        {    251,    [none]                        },
        {    252,    [unknown]                    },
        {    253,    [special]                    }
    }
    HANDLING    READ;
}

trans1_blk_dd_reference                     LIKE VARIABLE    phys_blk_dd_reference
{
}

trans1_blk_dd_rev                           LIKE VARIABLE    phys_blk_dd_rev
{
}

trans1_blk_profile                          LIKE VARIABLE    phys_blk_profile
{
}

trans1_blk_profile_rev                      LIKE VARIABLE    phys_blk_profile_rev
{
}

trans1_blk_execution_time                   LIKE VARIABLE    phys_blk_execution_time
{
}

trans1_blk_num_parameters                   LIKE VARIABLE    phys_blk_num_parameters
{
}

trans1_blk_index_view_1                     LIKE VARIABLE    phys_blk_index_view_1
{
}

trans1_blk_num_view_lists                   LIKE VARIABLE    phys_blk_num_view_lists
{
}

trans1_st_rev                               LIKE VARIABLE    phys_st_rev
{
}

trans1_tag_desc                             LIKE VARIABLE    phys_tag_desc
{
    REDEFINE LABEL        [MC_trans_tag_desc];
}

trans1_strategy                             LIKE VARIABLE    phys_strategy
{
}

trans1_alert_key                            LIKE VARIABLE    phys_alert_key
{
}

trans1_target_mode                            LIKE VARIABLE    phys_target_mode
{
}

trans1_actual_mode                            LIKE VARIABLE    phys_actual_mode
{
}

trans1_permitted_mode                        LIKE VARIABLE    phys_permitted_mode
{
}

trans1_normal_mode                            LIKE VARIABLE    phys_normal_mode
{
}

trans1_current_state_alarm_sum                LIKE VARIABLE    phys_current_state_alarm_sum
{
}

trans1_unacknowledged_state_alarm_sum        LIKE VARIABLE    phys_unacknowledged_state_alarm_sum
{
}

trans1_unreported_state_alarm_sum            LIKE VARIABLE    phys_unreported_state_alarm_sum
{
}

trans1_disabled_state_alarm_sum                LIKE VARIABLE    phys_disabled_state_alarm_sum
{
}

/*---------------------------------------------------------------------*/
/*    Transducer Block: Pressure Transmitter (m)                       */
/*---------------------------------------------------------------------*/
VARIABLE trans1_sensor_value
{
    LABEL        [trans_pres_sensor_value];
    HELP        [trans_pres_sensor_value_help];
    CLASS        CONTAINED & DYNAMIC;
    TYPE        FLOAT
    {
        DEFAULT_VALUE    0.0;
    }
    HANDLING    READ;
}

VARIABLE trans1_sensor_high_limit
{
    LABEL        [trans_sensor_upper_limit];        
    HELP        [trans_sensor_upper_limit_help];
    CLASS        CONTAINED;
    TYPE        FLOAT
    {
        DEFAULT_VALUE    1.0;
    }
    HANDLING    READ;
}

VARIABLE trans1_sensor_low_limit
{
    LABEL        [trans_sensor_lower_limit];        
    HELP        [trans_sensor_lower_limit_help];
    CLASS        CONTAINED;
    TYPE        FLOAT
    {
        DEFAULT_VALUE    0.0;
    }
    HANDLING    READ;
}

VARIABLE trans1_cal_point_hi
{
    LABEL        [trans_cal_point_hi];        
    HELP        [trans_cal_point_hi_help];
    CLASS        CONTAINED;
    TYPE        FLOAT
    {
        DEFAULT_VALUE    0.0;
    }
    HANDLING    READ & WRITE;
}

VARIABLE trans1_cal_point_lo
{
    LABEL        [trans_cal_point_lo];        
    HELP        [trans_cal_point_lo_help];
    CLASS        CONTAINED;
    TYPE        FLOAT
    {
        DEFAULT_VALUE    0.0;
    }
    HANDLING    READ & WRITE;
}

VARIABLE trans1_cal_min_span
{
    LABEL        [trans_cal_min_span];        
    HELP        [trans_cal_min_span_help];
    CLASS        CONTAINED;
    TYPE        FLOAT;
    HANDLING    READ;
}

VARIABLE trans1_sensor_unit
{
    LABEL        [trans_pres_sensor_unit];
    HELP        [trans_pres_sensor_unit_help];
    CLASS        CONTAINED;
    TYPE        ENUMERATED (2)
    {
        DEFAULT_VALUE    1133;
        PRESSURE_UNIT_LIST
    }
    HANDLING    READ & WRITE;
}

VARIABLE trans1_trimmed_value
{
    LABEL        [trans_pres_trimmed_value];
    HELP        [trans_pres_trimmed_value_help];
    CLASS        CONTAINED & DYNAMIC;
    TYPE        FLOAT
    {
        DEFAULT_VALUE    0.0;
    }

    HANDLING    READ;
}

VARIABLE trans1_trimmed_status_quality
{
    LABEL        [status_quality];
    HELP        [value_status_help];
    CLASS        CONTAINED & DYNAMIC;
    TYPE        ENUMERATED (1)
    {
        DEFAULT_VALUE    0;
        STATUS_OUTPUT_NO_RCAS
    }
    HANDLING    READ;
}

trans1_trimmed_status_limit            LIKE VARIABLE    trans1_trimmed_status_quality
{
    REDEFINE LABEL        [status_limit];        
    REDEFINE TYPE        ENUMERATED (1)
    {
        STATUS_OUTPUT_LIMIT
    }
}

VARIABLE trans1_sensor_type
{
    LABEL        [trans_sensor_type];
    HELP        [trans_pres_sensor_type_help];
    CLASS        CONTAINED;
    TYPE        ENUMERATED (2)
    {
        DEFAULT_VALUE  0;
        {    0,        [MC_trans_sensor_type_SC]},
        {    1,        [MC_trans_sensor_type_DS]}

    }
    HANDLING    READ;
}

VARIABLE trans1_sensor_ser_num
{
    LABEL        [trans_pres_sensor_serial_num];
    HELP        [trans_pres_sensor_serial_num_help];
    CLASS        CONTAINED;
    TYPE        UNSIGNED_INTEGER (4)
    {
        DEFAULT_VALUE   0;
    }
    HANDLING    READ;
}

VARIABLE trans1_primary_value
{
    LABEL        [trans_value];
    HELP        [trans_pres_value_help];
    CLASS        CONTAINED & DYNAMIC;
    TYPE        FLOAT;
    HANDLING    READ;
}

VARIABLE trans1_primary_value_status_quality
{
    LABEL        [status_quality];
    HELP        [value_status_help];
    CLASS        CONTAINED & DYNAMIC;
    TYPE        ENUMERATED (1)
    {
        DEFAULT_VALUE    0;
        STATUS_OUTPUT_NO_RCAS
    }
    HANDLING    READ;
}

trans1_primary_value_status_limit            LIKE VARIABLE    trans1_primary_value_status_quality
{
    REDEFINE LABEL        [status_limit];        
    REDEFINE TYPE        ENUMERATED (1)
    {
        STATUS_OUTPUT_LIMIT
    }
}

VARIABLE trans1_primary_value_type
{
    LABEL        [trans_pres_primary_value_type];
    HELP        [trans_pres_primary_value_type_help];
    CLASS        CONTAINED;
    TYPE        ENUMERATED (2)
    {
        {    0,        [trans_pres_primary_value_type_pres]    }
        /*
        ,    
        {    1,        [trans_pres_primary_value_type_flow]    },
        {    2,        [trans_pres_primary_value_type_level]    },
        {    3,        [trans_pres_primary_value_type_volume]    }
        */
    }
    HANDLING    READ & WRITE;
}

VARIABLE trans1_primary_value_unit
{
    LABEL        [trans_pres_primary_value_unit];
    HELP        [trans_pres_primary_value_unit_help];
    CLASS        CONTAINED;
    TYPE        ENUMERATED (2)
    {
        DEFAULT_VALUE    1133;
        PRESSURE_UNIT_LIST
    }
    HANDLING    READ & WRITE;    
}

/*---------------------------------------------------------------------*/
/*    Transducer Block: Pressure Transmitter (o)                       */
/*---------------------------------------------------------------------*/

VARIABLE trans1_diaphragm_mat
{
    LABEL        [trans_pres_sensor_diaphragm_mat];
    HELP        [trans_pres_sensor_diaphragm_mat_help];
    CLASS        CONTAINED;
    TYPE        ENUMERATED (2)
    {
        DEF_TRANS_DIAPHRAGM_MAT
    }    
    HANDLING    READ & WRITE;
}

VARIABLE trans1_sens_fill_fluid
{
    LABEL        [trans_pres_sensor_fill_fluid];
    HELP        [trans_pres_sensor_fill_fluid_help];
    CLASS        CONTAINED;
    TYPE        ENUMERATED (2)
    {
        DEF_TRANS_SENS_FILL_FLUID
    }
    HANDLING    READ & WRITE;
}

VARIABLE trans1_sensor_max_static_pres
{
    LABEL        [trans_pres_sensor_max_static_pres];
    HELP        [trans_pres_sensor_max_static_pres_help];
    CLASS        CONTAINED;
    TYPE        FLOAT;
    HANDLING    READ;
}

VARIABLE trans1_sensor_o_ring_mat
{
    LABEL        [trans_pres_sensor_o_ring_mat];
    HELP        [trans_pres_sensor_o_ring_mat_help];
    CLASS        CONTAINED;
    TYPE        ENUMERATED (2)
    {
        DEF_TRANS_SENSOR_O_RING_MAT
    }
    HANDLING    READ & WRITE;
}

VARIABLE trans1_proc_conn_type
{
    LABEL        [trans_pres_proc_conn_type];
    HELP        [trans_pres_proc_conn_type_help];
    CLASS        CONTAINED;
    TYPE        ENUMERATED (2)
    {
        DEF_TRANS_PROC_CONN_TYPE
    }
    HANDLING    READ & WRITE;    
}

VARIABLE trans1_proc_conn_mat
{
    LABEL        [trans_pres_proc_conn_mat];
    HELP        [trans_pres_proc_conn_mat_help];
    CLASS        CONTAINED;
    TYPE        ENUMERATED (2)
    {
        DEF_TRANS_PROC_CONN_MAT
    }
    HANDLING    READ & WRITE;
}

VARIABLE trans1_temperature_value
{
    LABEL        [trans_pres_sensor_temp_value];    
    HELP        [trans_pres_sensor_temp_value_help];
    CLASS        CONTAINED & DYNAMIC;
    TYPE        FLOAT;
    HANDLING    READ;
}

VARIABLE trans1_temperature_status_quality
{
    LABEL        [status_quality];
    HELP        [value_status_help];
    CLASS        CONTAINED & DYNAMIC;
    TYPE        ENUMERATED (1)
    {
        DEFAULT_VALUE    0;
        STATUS_OUTPUT_NO_RCAS
    }
    HANDLING    READ;
}

trans1_temperature_status_limit            LIKE VARIABLE    trans1_temperature_status_quality
{
    REDEFINE LABEL        [status_limit];        
    REDEFINE TYPE        ENUMERATED (1)
    {
        STATUS_OUTPUT_LIMIT
    }
}

VARIABLE trans1_temperature_unit
{
    LABEL        [trans_temperature_unit];
    HELP        [trans_temperature_unit_help];
    CLASS        CONTAINED;
    TYPE        ENUMERATED (2)
    {
        DEFAULT_VALUE    1001;
        /*
        { 1000,  [unit_1000],        [unit_1000_help]        },
        */
        { 1001,  [unit_1001],        [unit_1001_help]        }
        /*
        { 1002,  [unit_1002],        [unit_1002_help]        },
        { 1003,  [unit_1003],        [unit_1003_help]        }
        */
    }
    HANDLING    READ & WRITE;
}

VARIABLE trans1_secondary_value_1_value
{
    LABEL        [trans_secondary_value_1_value];
    HELP        [trans_pres_secondary_value_1_value_help];
    CLASS        CONTAINED & DYNAMIC;
    TYPE        FLOAT;
    HANDLING    READ;
}

VARIABLE trans1_secondary_value_1_status_quality
{
    LABEL        [status_quality];
    HELP        [value_status_help];
    CLASS        CONTAINED & DYNAMIC;
    TYPE        ENUMERATED (1)
    {
        DEFAULT_VALUE    0;
        STATUS_OUTPUT_NO_RCAS
    }
    HANDLING    READ;
}

trans1_secondary_value_1_status_limit            LIKE VARIABLE    trans1_secondary_value_1_status_quality
{
    REDEFINE LABEL        [status_limit];        
    REDEFINE TYPE        ENUMERATED (1)
    {
        STATUS_OUTPUT_LIMIT
    }
}

VARIABLE trans1_secondary_value_1_unit
{
    LABEL         [trans_secondary_value_1_unit];
    HELP          [trans_pres_secondary_value_1_unit_help];
    CLASS        CONTAINED ;
    TYPE        ENUMERATED (2)
    {
        DEFAULT_VALUE    1133;
        DEF_TRANS_SECONDARY_VALUE_1_UNIT
    }

    HANDLING      READ & WRITE;
}

VARIABLE trans1_secondary_value_2_value
{
    LABEL        [trans_secondary_value_2_value];
    HELP        [trans_pres_secondary_value_2_value_help];
    CLASS        CONTAINED & DYNAMIC;
    TYPE        FLOAT;
    HANDLING    READ;
}

VARIABLE trans1_secondary_value_2_status_quality
{
    LABEL        [status_quality];
    HELP        [value_status_help];
    CLASS        CONTAINED & DYNAMIC;
    TYPE        ENUMERATED (1)
    {
        DEFAULT_VALUE    0;
        STATUS_OUTPUT_NO_RCAS
    }
    HANDLING    READ;
}

trans1_secondary_value_2_status_limit            LIKE VARIABLE    trans1_secondary_value_2_status_quality
{
    REDEFINE LABEL        [status_limit];        
    REDEFINE TYPE        ENUMERATED (1)
    {
        STATUS_OUTPUT_LIMIT
    }
}

VARIABLE trans1_secondary_value_2_unit
{
    LABEL       [trans_secondary_value_2_unit];
    HELP        [trans_pres_secondary_value_2_unit_help];
    CLASS       CONTAINED;
    TYPE        ENUMERATED (2)
    {
        DEF_TRANS_SECONDARY_VALUE_2_UNIT
    }
    HANDLING      READ & WRITE;
}

VARIABLE trans1_lin_type
{
    LABEL        [trans_lin_type];    
    HELP        [trans_lin_type_help];
    CLASS        CONTAINED;
    TYPE        ENUMERATED (1)
    {
        DEF_TRANS_LIN_TYPE
    }
    HANDLING    READ & WRITE;
}

VARIABLE trans1_scale_in_lower_value
{
   LABEL         [trans_scale_in_lower_value];
   HELP          [trans_scale_in_lower_value_help];
   CLASS         CONTAINED;
   TYPE          FLOAT
    {
        DEFAULT_VALUE  0.0;
    }
   HANDLING      READ & WRITE;
}

VARIABLE trans1_scale_in_upper_value
{
   LABEL         [trans_scale_in_upper_value];
   HELP          [trans_scale_in_upper_value_help];
   CLASS         CONTAINED;
   TYPE          FLOAT
    {
        DEFAULT_VALUE  1.0;
    }
   HANDLING      READ & WRITE;
}

VARIABLE trans1_scale_out_lower_value
{
    LABEL         [trans_scale_out_lower_value];
    HELP          [trans_scale_out_lower_value_help];
    CLASS         CONTAINED;
    TYPE          FLOAT
    {
        DEFAULT_VALUE  0.0;
    }
    HANDLING      READ & WRITE;
}

VARIABLE trans1_scale_out_upper_value
{
   LABEL         [trans_scale_out_upper_value];
   HELP          [trans_scale_out_upper_value_help];
   CLASS         CONTAINED;
   TYPE          FLOAT
    {
        DEFAULT_VALUE  1.0;
    }
   HANDLING      READ & WRITE;
}

VARIABLE trans1_low_flow_cut_off
{
   LABEL         [trans_low_flow_cut_off];
   HELP          [trans_low_flow_cut_off_help];
   CLASS         CONTAINED;
   TYPE          FLOAT
    {
        DEFAULT_VALUE  0.0;
    }
   CONSTANT_UNIT    [unit_1342];
   HANDLING      READ & WRITE;
   VALIDITY VALID_SQUARE_ROOT
}

VARIABLE trans1_flow_lin_sqrt_point
{
   LABEL         [trans_flow_lin_sqrt_point];
   HELP          [trans_flow_lin_sqrt_point_help];
   CLASS         CONTAINED;
   TYPE          FLOAT
    {
        DEFAULT_VALUE  0.0;
    }
   CONSTANT_UNIT    [unit_1342];
   HANDLING      READ & WRITE;
   VALIDITY VALID_SQUARE_ROOT
}

/*
VARIABLE trans1_tab_actual_number
{
}

VARIABLE trans1_tab_entry
{
}

VARIABLE trans1_tab_max_number
{
}

VARIABLE trans1_tab_min_number
{
}

VARIABLE trans1_tab_op_code
{
}

VARIABLE trans1_tab_status
{
}

VARIABLE trans1_tab_x_value
{
}

VARIABLE trans1_tab_y_value
{
}
*/

VARIABLE trans1_max_sensor_value
{
    LABEL         [trans_pres_max_sensor_value];
    HELP          [trans_pres_max_sensor_value_help];
    CLASS         CONTAINED & DYNAMIC;
    TYPE          FLOAT;
    HANDLING      READ & WRITE;
}

VARIABLE trans1_min_sensor_value
{
    LABEL         [trans_pres_min_sensor_value];
    HELP          [trans_pres_min_sensor_value_help];
    CLASS         CONTAINED & DYNAMIC;
    TYPE          FLOAT;
    HANDLING      READ & WRITE;
}

VARIABLE trans1_max_temperature
{
    LABEL        [trans_pres_max_temperature];    
    HELP        [trans_pres_max_temperature_help];
    CLASS        CONTAINED & DYNAMIC;
    TYPE        FLOAT;
    HANDLING    READ & WRITE;
}

VARIABLE trans1_min_temperature
{
    LABEL        [trans_pres_min_temperature];    
    HELP        [trans_pres_min_temperature_help];
    CLASS        CONTAINED & DYNAMIC;
    TYPE        FLOAT;
    HANDLING    READ & WRITE;
}

VARIABLE trans1_zero_adjustment
{
    LABEL        [MC_trans_zero_adjustment];
    HELP        [MC_trans_zero_adjustment_help];
    CLASS        CONTAINED;
        TYPE        FLOAT
        {
        DEFAULT_VALUE    0.0;
    }

    HANDLING    READ & WRITE;
}

VARIABLE trans1_re_init_sensor_card
{
    LABEL        [MC_trans_re_init_sensor_card];
    HELP        [MC_trans_re_init_sensor_card_help];
    CLASS        CONTAINED;
    TYPE        ENUMERATED (1)
    {
        DEFAULT_VALUE    0;
        {    0,        [MC_NONE]    },
        {    0xff,    [MC_RE_INIT]}
    }

    HANDLING    READ & WRITE;
}

VARIABLE trans1_low_press_cut_off
{
    LABEL        [MC_trans_low_press_cut_off];
    HELP        [MC_trans_low_press_cut_off_help];
    CLASS        CONTAINED;
    TYPE        FLOAT
    {
        DEFAULT_VALUE    0.0;
    }

    HANDLING    READ & WRITE;
}

VARIABLE trans1_electronic_damping
{
    LABEL        "Electronic damping";
    HELP        "Electronic damping";
    CLASS        CONTAINED;
    TYPE        FLOAT
    {
        DEFAULT_VALUE    0.0;
    }
    CONSTANT_UNIT    "Sec";
    HANDLING    READ & WRITE;
}
/***********************************************************************/
/*    Unit relations                                                   */
/***********************************************************************/

/* Physical Block */
/* no unit relations */

/* Transducer Block 1: Pressure */
UNIT TB_TEMPERATURE_UNIT
{
    trans1_temperature_unit:
    trans1_temperature_value,
    trans1_min_temperature,
    trans1_max_temperature
}

UNIT TB_SENSOR_UNIT
{
    trans1_sensor_unit:
    
    trans1_sensor_value,
    trans1_sensor_high_limit,
    trans1_sensor_low_limit,
    trans1_cal_point_hi,
    trans1_cal_point_lo,
    trans1_cal_min_span,
    trans1_trimmed_value,
    trans1_min_sensor_value,
    trans1_max_sensor_value,
    trans1_zero_adjustment,
    trans1_sensor_max_static_pres
}

UNIT TB_PRIMARY_VALUE_UNIT
{
    trans1_primary_value_unit:

    trans1_scale_out_lower_value,
    trans1_scale_out_upper_value,
    trans1_primary_value
}

UNIT TB_SECONDARY_VALUE_1_UNIT
{
    trans1_secondary_value_1_unit:
    
    trans1_scale_in_lower_value,
    trans1_scale_in_upper_value,
    trans1_secondary_value_1_value,
    trans1_low_press_cut_off
}
//
//UNIT TB_SECONDARY_VALUE_2_UNIT
//{
//    trans1_secondary_value_2_unit:
//
//    trans1_secondary_value_2_value
//}

/*---------------------------------------------------------------------*/
/*    Commands                                                         */
/*---------------------------------------------------------------------*/

COMMAND read_trans1_blk
{
    BLOCK transducer_block_1;
    INDEX 0;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_blk_reserve,
            trans1_blk_object, 
            trans1_blk_parent_class, 
            trans1_blk_class,
            trans1_blk_dd_reference, 
            trans1_blk_dd_rev, 
            trans1_blk_profile, 
            trans1_blk_profile_rev,
            trans1_blk_execution_time, 
            trans1_blk_num_parameters, 
            trans1_blk_index_view_1,
            trans1_blk_num_view_lists
        }
    }
}

COMMAND read_trans1_st_rev
{
    BLOCK transducer_block_1;
    INDEX 1;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_st_rev
        }
    }
}

COMMAND read_trans1_tag_desc
{
    BLOCK transducer_block_1;
    INDEX 2;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_tag_desc
        }
    }
}

COMMAND write_trans1_tag_desc
{
    BLOCK transducer_block_1;
    INDEX 2;
    OPERATION WRITE;
    TRANSACTION
    {
        REQUEST
        {
            trans1_tag_desc
        }
        REPLY
        {
        }
    }
}

COMMAND read_trans1_strategy
{
    BLOCK transducer_block_1;
    INDEX 3;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_strategy
        }
    }
}

COMMAND write_trans1_strategy
{
    BLOCK transducer_block_1;
    INDEX 3;
    OPERATION WRITE;
    TRANSACTION
    {
        REQUEST
        {
            trans1_strategy
        }
        REPLY
        {
        }
    }
}

COMMAND read_trans1_alert_key
{
    BLOCK transducer_block_1;
    INDEX 4;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_alert_key
        }
    }
}

COMMAND write_trans1_alert_key
{
    BLOCK transducer_block_1;
    INDEX 4;
    OPERATION WRITE;
    TRANSACTION
    {
        REQUEST
        {
            trans1_alert_key
        }
        REPLY
        {
        }
    }
}

COMMAND read_trans1_target_mode
{
    BLOCK transducer_block_1;
    INDEX 5;
    OPERATION  READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_target_mode
        }
    }
}

COMMAND write_trans1_target_mode
{
    BLOCK transducer_block_1;
    INDEX 5;
    OPERATION  WRITE;
    TRANSACTION
    {
        REQUEST
        {
            trans1_target_mode
        }
        REPLY
        {
        }
    }
}


COMMAND read_trans1_mode
{
    BLOCK transducer_block_1;
    INDEX 6;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_actual_mode,
            trans1_permitted_mode,
            trans1_normal_mode
        }
    }
}

COMMAND read_trans1_alarm
{
    BLOCK transducer_block_1;
    INDEX 7;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_current_state_alarm_sum, 
            trans1_unacknowledged_state_alarm_sum,
            trans1_unreported_state_alarm_sum, 
            trans1_disabled_state_alarm_sum
        }
    }
}

COMMAND read_trans1_sensor_value
{
    BLOCK transducer_block_1;
    INDEX 8;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_sensor_value
        }
    }
}

COMMAND read_trans1_sensor_high_limit
{
    BLOCK transducer_block_1;
    INDEX 9;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_sensor_high_limit
        }
    }
}

COMMAND read_trans1_sensor_low_limit
{
    BLOCK transducer_block_1;
    INDEX 10;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_sensor_low_limit
        }
    }
}

COMMAND read_trans1_cal_point_hi
{
    BLOCK transducer_block_1;
    INDEX 11;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_cal_point_hi
        }
    }
}

COMMAND write_trans1_cal_point_hi
{
    BLOCK transducer_block_1;
    INDEX 11;
    OPERATION WRITE;
    TRANSACTION
    {
        REQUEST
        {
            trans1_cal_point_hi
        }
        REPLY
        {
        }
    }
}

COMMAND read_trans1_cal_point_lo
{
    BLOCK transducer_block_1;
    INDEX 12;
    OPERATION  READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_cal_point_lo
        }
    }
}

COMMAND write_trans1_cal_point_lo
{
    BLOCK transducer_block_1;
    INDEX 12;
    OPERATION  WRITE;
    TRANSACTION
    {
        REQUEST
        {
            trans1_cal_point_lo
        }
        REPLY
        {
        }
    }
}

COMMAND read_trans1_cal_min_span
{
    BLOCK transducer_block_1;
    INDEX 13;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_cal_min_span
        }
    }
}

COMMAND read_trans1_sensor_unit
{
    BLOCK transducer_block_1;
    INDEX 14;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_sensor_unit
        }
    }
}

COMMAND write_trans1_sensor_unit
{
    BLOCK transducer_block_1;
    INDEX 14;
    OPERATION WRITE;
    TRANSACTION
    {
        REQUEST
        {
            trans1_sensor_unit
        }
        REPLY
        {            
        }
    }
}

COMMAND read_trans1_trimmed_value
{
    BLOCK transducer_block_1;
    INDEX 15;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_trimmed_value,
            trans1_trimmed_status_quality    <0xFC>,
            trans1_trimmed_status_limit        <0x03>
        }
    }
}

COMMAND read_trans1_sensor_type
{
    BLOCK transducer_block_1;
    INDEX 16;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
             trans1_sensor_type
        }
    }
}

COMMAND read_trans1_sensor_ser_num
{
    BLOCK transducer_block_1;
    INDEX 17;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_sensor_ser_num
        }
    }
}

COMMAND read_trans1_primary
{
    BLOCK transducer_block_1;
    INDEX 18;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_primary_value,
            trans1_primary_value_status_quality    <0xFC>,
            trans1_primary_value_status_limit    <0x03>
        }
    }
}

COMMAND read_trans1_primary_value_unit
{
    BLOCK transducer_block_1;
    INDEX 19;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_primary_value_unit
        }
    }
}

COMMAND write_trans1_primary_value_unit
{
    BLOCK transducer_block_1;
    INDEX 19;
    OPERATION WRITE;
    TRANSACTION
    {
        REQUEST
        {
            trans1_primary_value_unit
        }
        REPLY
        {
        }
    }
}

COMMAND read_trans1_primary_value_type
{
    BLOCK transducer_block_1;
    INDEX 20;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_primary_value_type
        }
    }
}

COMMAND write_trans1_primary_value_type
{
    BLOCK transducer_block_1;
    INDEX 20;
    OPERATION WRITE;
    TRANSACTION
    {
        REQUEST
        {
            trans1_primary_value_type
        }
        REPLY
        {
        }
    }
}

COMMAND read_trans1_diaphragm_mat
{
    BLOCK transducer_block_1;
    INDEX 21;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_diaphragm_mat
        }
    }
}

COMMAND write_trans1_diaphragm_mat
{
    BLOCK transducer_block_1;
    INDEX 21;
    OPERATION WRITE;
    TRANSACTION
    {
        REQUEST
        {
            trans1_diaphragm_mat
        }
        REPLY
        {
        }
    }
}

COMMAND read_trans1_sens_fill_fluid
{
    BLOCK transducer_block_1;
    INDEX 22;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_sens_fill_fluid
        }
    }
}

COMMAND write_trans1_sens_fill_fluid
{
    BLOCK transducer_block_1;
    INDEX 22;
    OPERATION WRITE;
    TRANSACTION
    {
        REQUEST
        {
            trans1_sens_fill_fluid
        }
        REPLY
        {
        }
    }
}

COMMAND read_trans1_sensor_max_static_pres
{
    BLOCK transducer_block_1;
    INDEX 23;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_sensor_max_static_pres
        }
    }
}

COMMAND read_trans1_sensor_o_ring_mat
{
    BLOCK transducer_block_1;
    INDEX 24;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_sensor_o_ring_mat
        }
    }
}

COMMAND write_trans1_sensor_o_ring_mat
{
    BLOCK transducer_block_1;
    INDEX 24;
    OPERATION WRITE;
    TRANSACTION
    {
        REQUEST
        {
            trans1_sensor_o_ring_mat
        }
        REPLY
        {
        }
    }
}

COMMAND read_trans1_proc_conn_type
{
    BLOCK transducer_block_1;
    INDEX 25;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_proc_conn_type
        }
    }
}

COMMAND write_trans1_proc_conn_type
{
    BLOCK transducer_block_1;
    INDEX 25;
    OPERATION WRITE;
    TRANSACTION
    {
        REQUEST
        {
            trans1_proc_conn_type
        }
        REPLY
        {
        }
    }
}

COMMAND read_trans1_proc_conn_mat
{
    BLOCK transducer_block_1;
    INDEX 26;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_proc_conn_mat
        }
    }
}

COMMAND write_trans1_proc_conn_mat
{
    BLOCK transducer_block_1;
    INDEX 26;
    OPERATION WRITE;
    TRANSACTION
    {
        REQUEST
        {
            trans1_proc_conn_mat
        }
        REPLY
        {
        }
    }
}

COMMAND read_trans1_temperature
{
    BLOCK transducer_block_1;
    INDEX 27;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_temperature_value,
            trans1_temperature_status_quality    <0xFC>,
            trans1_temperature_status_limit    <0x03>
        }
    }
}

COMMAND read_trans1_temperature_unit
{
    BLOCK transducer_block_1;
    INDEX 28;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_temperature_unit
        }
    }
}

COMMAND write_trans1_temperature_unit
{
    BLOCK transducer_block_1;
    INDEX 28;
    OPERATION WRITE;
    TRANSACTION
    {
        REQUEST
        {
            trans1_temperature_unit
        }
        REPLY
        {
        }
    }
}

COMMAND read_trans1_secondary_value_1
{
    BLOCK transducer_block_1;
    INDEX 29;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_secondary_value_1_value, 
            trans1_secondary_value_1_status_quality    <0xFC>,
            trans1_secondary_value_1_status_limit    <0x03>
        }
    }
}

COMMAND  read_trans1_secondary_value_1_unit
{
     BLOCK transducer_block_1;
     INDEX 30;
     OPERATION READ;
     TRANSACTION
     {
          REQUEST
          {
          }
          REPLY
          {
               trans1_secondary_value_1_unit
          }
     }
}
 
COMMAND  write_trans1_secondary_value_1_unit
{
     BLOCK transducer_block_1;
     INDEX 30;
     OPERATION WRITE;
     TRANSACTION
     {
          REQUEST
          {
               trans1_secondary_value_1_unit
          }
          REPLY
          {
          }
     }
}

COMMAND read_trans1_secondary_value_2
{
    BLOCK transducer_block_1;
    INDEX 31;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_secondary_value_2_value, 
            trans1_secondary_value_2_status_quality    <0xFC>,
            trans1_secondary_value_2_status_limit    <0x03>
        }
    }
}

COMMAND  read_trans1_secondary_value_2_unit
{
     BLOCK transducer_block_1;
     INDEX 32;
     OPERATION READ;
     TRANSACTION
     {
          REQUEST
          {
          }
          REPLY
          {
               trans1_secondary_value_2_unit
          }
     }
}
 
COMMAND  write_trans1_secondary_value_2_unit
{
     BLOCK transducer_block_1;
     INDEX 32;
     OPERATION WRITE;
     TRANSACTION
     {
          REQUEST
          {
               trans1_secondary_value_2_unit
          }
          REPLY
          {
          }
     }
}

COMMAND read_trans1_lin_type
{
    BLOCK transducer_block_1;
    INDEX 33;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_lin_type
        }
    }
}

COMMAND write_trans1_lin_type
{
    BLOCK transducer_block_1;
    INDEX 33;
    OPERATION WRITE;
    TRANSACTION
    {
        REQUEST
        {
            trans1_lin_type
        }
        REPLY
        {
        }
    }
}

COMMAND  read_trans1_scale_in
{
     BLOCK transducer_block_1;
     INDEX 34;
     OPERATION READ;
     TRANSACTION
     {
          REQUEST
          {
          }
          REPLY
          {
                trans1_scale_in_upper_value,
                trans1_scale_in_lower_value
                
          }
     }
}
 
COMMAND  write_trans1_scale_in
{
     BLOCK transducer_block_1;
     INDEX 34;
     OPERATION WRITE;
     TRANSACTION
     {
          REQUEST
          {
                trans1_scale_in_upper_value,
                trans1_scale_in_lower_value
          }
          REPLY
          {
          }
     }
}

COMMAND  read_trans1_scale_out
{
     BLOCK transducer_block_1;
     INDEX 35;
     OPERATION READ;
     TRANSACTION
     {
          REQUEST
          {
          }
          REPLY
          {
                trans1_scale_out_upper_value,
                trans1_scale_out_lower_value
          }
     }
}
 
COMMAND  write_trans1_scale_out
{
    BLOCK transducer_block_1;
    INDEX 35;
    OPERATION WRITE;
    TRANSACTION
    {
        REQUEST
        {
                trans1_scale_out_upper_value,
                trans1_scale_out_lower_value
        }
        REPLY
        {
        }
    }
}

COMMAND  read_trans1_low_flow_cut_off
{
     BLOCK transducer_block_1;
     INDEX 36;
     OPERATION READ;
     TRANSACTION
     {
          REQUEST
          {
          }
          REPLY
          {
               trans1_low_flow_cut_off
          }
     }
}
 
COMMAND  write_trans1_low_flow_cut_off
{
     BLOCK transducer_block_1;
     INDEX 36;
     OPERATION WRITE;
     TRANSACTION
     {
          REQUEST
          {
               trans1_low_flow_cut_off
          }
          REPLY
          {
          }
     }
}

COMMAND  read_trans1_flow_lin_sqrt_point
{
     BLOCK transducer_block_1;
     INDEX 37;
     OPERATION READ;
     TRANSACTION
     {
          REQUEST
          {
          }
          REPLY
          {
               trans1_flow_lin_sqrt_point
          }
     }
}
 
COMMAND  write_trans1_flow_lin_sqrt_point
{
     BLOCK transducer_block_1;
     INDEX 37;
     OPERATION WRITE;
     TRANSACTION
     {
          REQUEST
          {
               trans1_flow_lin_sqrt_point
          }
          REPLY
          {
          }
     }
}

COMMAND  read_trans1_max_sensor_value
{
     BLOCK transducer_block_1;
     INDEX 45;
     OPERATION READ;
     TRANSACTION
     {
          REQUEST
          {
          }
          REPLY
          {
               trans1_max_sensor_value
          }
     }
}
 
COMMAND  write_trans1_max_sensor_value
{
     BLOCK transducer_block_1;
     INDEX 45;
     OPERATION WRITE;
     TRANSACTION
     {
          REQUEST
          {
               trans1_max_sensor_value
          }
          REPLY
          {
          }
     }
}

COMMAND  read_trans1_min_sensor_value
{
     BLOCK transducer_block_1;
     INDEX 46;
     OPERATION READ;
     TRANSACTION
     {
          REQUEST
          {
          }
          REPLY
          {
               trans1_min_sensor_value
          }
     }
}
 
COMMAND  write_trans1_min_sensor_value
{
     BLOCK transducer_block_1;
     INDEX 46;
     OPERATION WRITE;
     TRANSACTION
     {
          REQUEST
          {
               trans1_min_sensor_value
          }
          REPLY
          {
          }
     }
}

COMMAND read_trans1_max_temperature
{
    BLOCK transducer_block_1;
    INDEX 47;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_max_temperature
        }
    }
}

COMMAND write_trans1_max_temperature
{
    BLOCK transducer_block_1;
    INDEX 47;
    OPERATION WRITE;
    TRANSACTION
    {
        REQUEST
        {
            trans1_max_temperature
        }
        REPLY
        {
        }
    }
}

COMMAND read_trans1_min_temperature
{
    BLOCK transducer_block_1;
    INDEX 48;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_min_temperature
        }
    }
}

COMMAND write_trans1_min_temperature
{
    BLOCK transducer_block_1;
    INDEX 48;
    OPERATION WRITE;
    TRANSACTION
    {
        REQUEST
        {
            trans1_min_temperature
        }
        REPLY
        {
        }
    }
}

COMMAND read_trans1_zero_adjustment
{
    BLOCK transducer_block_1;
    INDEX 59;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_zero_adjustment
        }
    }
}

COMMAND write_trans1_zero_adjustment
{
    BLOCK transducer_block_1;
    INDEX 59;
    OPERATION WRITE;
    TRANSACTION
    {
        REQUEST
        {
            trans1_zero_adjustment
        }
        REPLY
        {
        }
    }
}

COMMAND read_trans1_re_init_sensor_card
{
    BLOCK transducer_block_1;
    INDEX 60;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_re_init_sensor_card
        }
    }
}

COMMAND write_trans1_re_init_sensor_card
{
    BLOCK transducer_block_1;
    INDEX 60;
    OPERATION WRITE;
    TRANSACTION
    {
        REQUEST
        {
            trans1_re_init_sensor_card
        }
        REPLY
        {
        }
    }
}

COMMAND read_trans1_low_press_cut_off
{
    BLOCK transducer_block_1;
    INDEX 61;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_low_press_cut_off
        }
    }
}

COMMAND write_trans1_low_press_cut_off
{
    BLOCK transducer_block_1;
    INDEX 61;
    OPERATION WRITE;
    TRANSACTION
    {
        REQUEST
        {
            trans1_low_press_cut_off
        }
        REPLY
        {
        }
    }
}

COMMAND read_trans1_electronic_damping
{
    BLOCK transducer_block_1;
    INDEX 62;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_electronic_damping
        }
    }
}

COMMAND write_trans1_electronic_damping
{
    BLOCK transducer_block_1;
    INDEX 62;
    OPERATION WRITE;
    TRANSACTION
    {
        REQUEST
        {
            trans1_electronic_damping
        }
        REPLY
        {
        }
    }
}

/***********************************************************************/
/*****    Menu: Specialist  **********************************************/
/***********************************************************************/

MENU Menu_Main_Specialist
{
    LABEL        [main_menu];
    ITEMS
    {
        Menu_File,
        Menu_S_Device,
        Menu_S_View,
        Menu_Options,
        Menu_Help
    }
}

/***********************************************************************/
/*****    Menu: Maintenance  *********************************************/
/***********************************************************************/

MENU Menu_Main_Maintenance
{
    LABEL        [main_menu];
    ITEMS
    {
        Menu_File,
        Menu_M_Device,
        Menu_M_View,
        Menu_Options,
        Menu_Help
    }
}

MENU download_variables
{
    LABEL        [menu_load_to_PC];
    ITEMS
    {
    /* PHYSICAL BLOCK    */
        phys_st_rev,
        phys_device_man_id,
        phys_device_id,
        phys_tag_desc,
        phys_descriptor,
        phys_message,
        phys_install_date,
        phys_software_rev,
        phys_hardware_rev,
        phys_blk_profile,
        phys_blk_profile_rev,
        phys_blk_dd_reference,
        phys_blk_dd_rev,
        phys_device_certification,
        phys_device_ser_num,
        phys_write_locking,
        phys_lcd_dsp_type_index,
        phys_lcd_dsp_decimal_point,

    /* TRANDSDUCER BLOCK 1: PRESSURE    */
        trans1_st_rev,
        trans1_tag_desc,
        trans1_sensor_ser_num,
        trans1_sensor_type,
        trans1_primary_value_type,
        trans1_sensor_unit,
        trans1_sensor_low_limit,
        trans1_sensor_high_limit,
        trans1_secondary_value_1_unit,
        trans1_scale_in_lower_value,
        trans1_scale_in_upper_value,
        trans1_primary_value_unit,
        trans1_scale_out_lower_value,
        trans1_scale_out_upper_value,
        trans1_lin_type,
        trans1_low_flow_cut_off,
        trans1_flow_lin_sqrt_point,
        trans1_cal_point_lo,
        trans1_cal_point_hi,
        /*trans1_cal_min_span,*/
        trans1_sens_fill_fluid,
        trans1_diaphragm_mat,
        trans1_sensor_o_ring_mat,
        trans1_proc_conn_type,
        trans1_proc_conn_mat,
        trans1_sensor_max_static_pres,
        trans1_temperature_unit,
        trans1_zero_adjustment,
        trans1_low_press_cut_off,
        trans1_electronic_damping

        IF (trans1_actual_mode == BLOCK_MODE_OUT_OF_SERVICE)
        {
            trans1_re_init_sensor_card
        }
        ELSE
        {}



    /* FUNCTION BLOCK 1: AI    */
        func1_AI_st_rev,
        func1_AI_tag_desc,
        func1_AI_batch_id,
        func1_AI_batch_unit,
        func1_AI_batch_operation,
        func1_AI_batch_phase,
        func1_AI_channel,
        func1_AI_pv_ftime,
        func1_AI_target_mode,
        func1_AI_actual_mode,
        func1_AI_permitted_mode,
        func1_AI_normal_mode,
        func1_AI_pv_lower_range_value,
        func1_AI_pv_upper_range_value,
        func1_AI_out_lower_range_value,
        func1_AI_out_upper_range_value,
        func1_AI_out_unit,
        func1_AI_out_decimal_point,
        func1_AI_hi_hi_lim,
        func1_AI_hi_lim,
        func1_AI_lo_lim,
        func1_AI_lo_lo_lim,
        func1_AI_alarm_hys,
        func1_AI_FSafeType,
        func1_AI_FSafeValue
    }
}

MENU upload_variables
{
    LABEL        [menu_load_to_device];
    ITEMS
    {
    /* PHYSICAL BLOCK    */
        phys_tag_desc,
        phys_descriptor,
        phys_message,
        phys_install_date,
        //phys_ident_number,
        //phys_write_locking,
        phys_local_operation_enable,
        phys_strategy,
        phys_alert_key,
        phys_lcd_dsp_type_index,
        phys_lcd_dsp_decimal_point,

    /* TRANDSDUCER BLOCK 1: PRESSURE    */
        trans1_tag_desc,
        trans1_strategy,
        trans1_alert_key,
        trans1_sensor_unit,
        trans1_primary_value_type,
        trans1_primary_value_unit,
        /*trans1_temperature_unit,*/
        trans1_secondary_value_1_unit,
        /*trans1_secondary_value_2_unit,*/
        trans1_scale_in_lower_value,
        trans1_scale_in_upper_value,
        trans1_scale_out_lower_value,
        trans1_scale_out_upper_value,
        trans1_low_press_cut_off,
        trans1_electronic_damping,

        trans1_lin_type
        IF ((trans1_primary_value_type == 1) && (trans1_lin_type == 10))
        {
            trans1_low_flow_cut_off,
            trans1_flow_lin_sqrt_point
        }

        trans1_diaphragm_mat,
        trans1_sens_fill_fluid,
        trans1_sensor_o_ring_mat,

        trans1_proc_conn_type,
        trans1_proc_conn_mat,


    /* FUNCTION BLOCK 1: AI    */
        func1_AI_tag_desc,
        func1_AI_strategy,
        func1_AI_alert_key,
        func1_AI_target_mode,
        func1_AI_batch_id,
        func1_AI_batch_unit,
        func1_AI_batch_operation,
        func1_AI_batch_phase,
        func1_AI_channel,
        func1_AI_lin_type,
        func1_AI_pv_ftime,
        func1_AI_pv_upper_range_value,
        func1_AI_pv_lower_range_value,
        func1_AI_out_upper_range_value,
        func1_AI_out_lower_range_value,
        func1_AI_out_unit,
        func1_AI_out_decimal_point,
        func1_AI_alarm_hys,
        func1_AI_hi_hi_lim,
        func1_AI_hi_lim,
        func1_AI_lo_lim,
        func1_AI_lo_lo_lim,
        func1_AI_FSafeType,
        func1_AI_FSafeValue,
        func1_AI_out_unit_text
    }
    PRE_READ_ACTIONS
    {
            method_pre_write_phys_write_locking
    }
}

/*---------------------------------------------------------------------*/
/*    Menu: Device                                                     */
/*---------------------------------------------------------------------*/

MENU Menu_S_Device
{
    LABEL        [menu_Device];
    ITEMS
    {
        std_NodeAddress,
        COLUMNBREAK,
        std_LoadinDevice,
        std_LoadinPC,
        COLUMNBREAK,
        Menu_online,
        Menu_offline,
        Menu_cal,
        OnlineWindow_simulation,
        COLUMNBREAK,
        OnlineDialog_reset,
        OnlineDialog_write_locking,
        OnlineDialog_ident_number
    }
}

MENU Menu_M_Device
{
    LABEL        [menu_Device];
    ITEMS
    {
        std_NodeAddress,
        COLUMNBREAK,
        std_LoadinDevice,
        std_LoadinPC//,
//        SEPARATOR,
//        Menu_online,
//        Menu_offline,
//        Menu_cal,
    }
}

MENU Menu_online
{
    LABEL [MC_Online_Conf];
    ITEMS
    {
        Menu_ai_online
    }
}

MENU Menu_offline
{
    LABEL [MC_Offline_Conf];
    ITEMS
    {
        OfflineWindow_trans_setting,
        OfflineWindow_ai_geral,
        OfflineWindow_LCD_display
    }
}

MENU OfflineWindow_trans_setting
{
    LABEL [trans1];
    ITEMS
    {
        Page_trans_setting,
        Page_trans_scales_units
    }
}

MENU Page_trans_setting
{
    LABEL [MC_Settings];
    ITEMS
    {
        Group_Primary_Value_Type,
        Group_Lin_Type
    }
}

MENU Group_Primary_Value_Type
{
    LABEL [MC_Select_Transmitter_Type];
    ITEMS
    {
        trans1_primary_value_type (READ_ONLY)
    }
}

MENU Group_Lin_Type
{
    LABEL [MC_Select_Lin_Type];
    ITEMS
    {
        trans1_lin_type,
        trans1_low_press_cut_off,
        COLUMNBREAK,
        method_write_lin_type
    }
}

MENU Page_trans_scales_units
{
    LABEL [MC_Scales_Units];
    ITEMS
    {
        Group_scale_in,
        Group_secondary_value_1_unit,
        Group_scale_out,
        Group_primary_value_unit,
        Group_temperature_unit
    }
}

MENU Group_scale_in
{
    LABEL [MC_Set_Scale_of_Pressure_Value];
    ITEMS
    {
        trans1_scale_in_lower_value,
        trans1_scale_in_upper_value,
        COLUMNBREAK,
        method_write_scale_in
    }
}

MENU Group_secondary_value_1_unit
{
    LABEL [MC_Select_Pressure_Unit];
    ITEMS
    {
        trans1_secondary_value_1_unit,
        COLUMNBREAK,
        method_write_secondary_value_1_unit
    }
}

MENU Group_scale_out
{
    LABEL [MC_Set_Scale_of_Output_Value];
    ITEMS
    {
        trans1_scale_out_lower_value,
        trans1_scale_out_upper_value,
        COLUMNBREAK,
        method_write_scale_out
    }
}

MENU Group_primary_value_unit
{
    LABEL [MC_Select_Output_Unit];
    ITEMS
    {
        trans1_primary_value_unit,
        COLUMNBREAK,
        method_write_trans1_primary_value_unit
    }
}

MENU Group_temperature_unit
{
    LABEL [MC_Select_Temperature_Unit];
    ITEMS
    {
        trans1_temperature_unit,
        COLUMNBREAK,
        method_write_temperature_unit
    }
}

MENU Menu_cal
{
    LABEL        [MC_menu_cal];
    ITEMS
    {
        OnlineDialog_cal_pressure,
        OnlineDialog_zero_adjustment
    }
}

MENU OnlineDialog_cal_pressure
{
    LABEL        [MC_cal_pressure];
    ITEMS
    {
        Page_cal_sensor_unit,
        Page_cal_lo_point,
        Page_cal_hi_point
    }
}


MENU Page_cal_sensor_unit
{
    LABEL     [trans_cal_unit];
    ITEMS
    {
        trans1_sensor_unit
    }
}

MENU Page_cal_lo_point
{
    LABEL     [MC_cal_lo_point];
    ITEMS
    {
        trans1_sensor_low_limit (READ_ONLY),
        trans1_cal_point_lo(READ_ONLY),
        Group_trimmed_value,
        COLUMNBREAK,
        method_set_cal_point_lo
    }
}

MENU Page_cal_hi_point
{
    LABEL     [MC_cal_hi_point];
    ITEMS
    {
        trans1_sensor_high_limit (READ_ONLY),
        trans1_cal_point_hi(READ_ONLY),
        Group_trimmed_value,
        COLUMNBREAK,
        method_set_cal_point_hi
    }
}

MENU Group_trimmed_value
{
    LABEL     [MC_trimmed_value];
    ITEMS
    {
        trans1_trimmed_value,
        COLUMNBREAK,
        trans1_trimmed_status_quality,
        trans1_trimmed_status_limit
    }
}

MENU OnlineDialog_zero_adjustment
{
    LABEL     [MC_zero_adjustment];
    ITEMS
    {
        Page_zero_adjustment
    }
}

MENU Page_zero_adjustment
{
    LABEL     [MC_zero_adjustment];
    ITEMS
    {
        trans1_secondary_value_1_value,
        trans1_zero_adjustment,
        method_set_trans1_zero_adjustment
    }
}

MENU OnlineWindow_simulation
{
    LABEL        [menu_dialog_simulation];
    ITEMS
    {
        Page_simulation_input_func1,
        Page_simulation_output_func1
    }
}

/*---------------------------------------------------------------------*/
/*    Menu: View                                                       */
/*---------------------------------------------------------------------*/
MENU Menu_S_View
{
    LABEL        [menu_View];
    ITEMS
    {
        OnlineWindow_display,
        SEPARATOR,
        OnlineWindow_yt,
        Menu_S_alarm,
        OnlineWindow_diagnosis,
        OnlineWindow_indicators,
        SEPARATOR,
        std_Funktionsleiste,
        std_Statuszeile,
        SEPARATOR,
        std_Update     
        }
}

MENU Menu_M_View
{
    LABEL        [menu_View];
    ITEMS
    {
        OnlineWindow_display,
        SEPARATOR,
        OnlineWindow_yt,
        Menu_S_alarm,
        OnlineWindow_diagnosis,
        OnlineWindow_indicators,
        SEPARATOR,
        std_Funktionsleiste,
        std_Statuszeile,
        SEPARATOR,
        std_Update
        }
}

MENU OnlineWindow_display
{
    LABEL        [menu_dialog_display];
    ITEMS
    {
        Page_display_trans1,
        Page_display_func1
    }
}

MENU Page_display_trans1
{
    LABEL        [trans1];
    ITEMS
    {
        BarVal_display_measure,
        Val_display_Sensor_Value,
        Group_display_Secondary_Value_1,
        Group_display_Secondary_Value_2,
        Group_display_Primary_Value,
        Group_display_temp_measure
    }
}

MENU BarVal_display_measure
{
    LABEL        [menu_dialog_display_measure];
    ITEMS
    {
        trans1_primary_value            (READ_ONLY),
        trans1_scale_out_lower_value    (READ_ONLY),
        trans1_scale_out_upper_value    (READ_ONLY)
    }
}

MENU Val_display_Sensor_Value
{
    LABEL        [trans_pres_sensor_value];
    ITEMS
    {
        trans1_sensor_value
    }
}

MENU Group_display_Primary_Value
{
    LABEL        [MC_Primary_Value];
    ITEMS
    {
        trans1_primary_value                    (READ_ONLY),
        COLUMNBREAK,
        trans1_primary_value_status_quality     (READ_ONLY),
        trans1_primary_value_status_limit        (READ_ONLY)
    }
}


MENU Group_display_Secondary_Value_1
{
    LABEL        [MC_Secondary_Value_1];
    ITEMS
    {
        trans1_secondary_value_1_value              (READ_ONLY),
        COLUMNBREAK,
        trans1_secondary_value_1_status_quality     (READ_ONLY),
        trans1_secondary_value_1_status_limit        (READ_ONLY)
    }
}

MENU Group_display_Secondary_Value_2
{
    LABEL        [MC_Secondary_Value_2];
    ITEMS
    {
        trans1_secondary_value_2_value              (READ_ONLY),
        COLUMNBREAK,
        trans1_secondary_value_2_status_quality     (READ_ONLY),
        trans1_secondary_value_2_status_limit        (READ_ONLY)
    }
}

MENU Group_display_temp_measure
{
    LABEL        [MC_Temperature];
    ITEMS
    {
        trans1_temperature_value            (READ_ONLY),
        COLUMNBREAK,
        trans1_temperature_status_quality   (READ_ONLY),
        trans1_temperature_status_limit     (READ_ONLY)
    }
}

MENU Menu_S_alarm
{
    LABEL        [menu_dialog_alarm];
    ITEMS
    {
        OnlineWindow_S_alarm_func1
    }
}

MENU OnlineWindow_diagnosis
{
    LABEL        [menu_dialog_diagnosis];
    ITEMS
    {
        Page_diagnosis_general,
        Page_diagnosis_phys_block,
        Page_diagnosis_trans_block,
        Page_diagnosis_func1
    }
}

MENU Page_diagnosis_trans_block
{
    LABEL        [trans1_block];
    ITEMS
    {
        trans1_blk_object,
        trans1_blk_parent_class,
        trans1_blk_class,
        trans1_blk_dd_reference,
        trans1_blk_dd_rev,
        trans1_blk_profile,
        trans1_blk_profile_rev,
        trans1_st_rev,
        trans1_actual_mode
    }
}

MENU OnlineWindow_indicators
{
    LABEL        [menu_indicator];
    ITEMS
    {
        Page_pressure_pointer,
        Page_sens_temp_pointer
    }
}

MENU Page_pressure_pointer
{
    LABEL        [menu_pres_indicator];
    ITEMS
    {
        trans1_min_sensor_value        (READ_ONLY),
        trans1_max_sensor_value        (READ_ONLY),
        reset_pressure_pointer
    }
}

MENU Page_sens_temp_pointer
{
    LABEL        [menu_sens_temp_indicator];
    ITEMS
    {
        trans1_min_temperature        (READ_ONLY),
        trans1_max_temperature        (READ_ONLY),
        reset_temperatur_pointer
    }
}

/*---------------------------------------------------------------------*/
/*    Menu: Options                                                    */
/*---------------------------------------------------------------------*/

//MENU Menu_Options
//{
//    LABEL           [menu_Options];
//    ITEMS
//    {
//        std_Einstellungen,
//        std_Untereintraege,
//        SEPARATOR,
//        OfflineDialog_CommErrorHandling
//    }
//}

/***********************************************************************/
/*****    Table: Specialist    *****************************************/
/***********************************************************************/

MENU Table_Main_Specialist
{
    LABEL    [MC_Table_Main_Specialist];
    ITEMS
    {
        Tab_s_info,
        Tab_s_trd,
        Tab_s_ai,               /* file AI1_Blk1.inc  */
        Tab_s_lcd
    }
}

MENU Tab_s_info
{
    LABEL    [MC_Tab_info];
    ITEMS
    {
        Tab_s_manuf_info,       /* file Phys_Blk.inc */
        Tab_s_block_tag,
        Tab_s_get_info,         /* file Phys_Blk.inc */
        Tab_serial_numbers,     /* file Phys_Blk.inc */
        Tab_device_revisions,   /* file Phys_Blk.inc */
        Tab_s_certificates      /* file Phys_Blk.inc */
    }
}

MENU Tab_s_block_tag
{
    LABEL    [MC_Tab_block_tag];
    ITEMS
    {
        phys_tag_desc,
        trans1_tag_desc,
        func1_AI_tag_desc
    }
}

MENU Tab_serial_numbers
{
    LABEL   [MC_Tab_serial_numbers];
    ITEMS
    {
        phys_device_ser_num   (READ_ONLY),
        trans1_sensor_ser_num (READ_ONLY),
        trans1_sensor_type
    }
}

MENU Tab_s_trd
{
    LABEL   [trans1];
    ITEMS
    {
        trans1_st_rev,
        Tab_s_pv_type,
        Tab_s_trans1_input_meassurelimit,
        Tab_s_trans1_input_meassurerange,
        Tab_s_trans1_input_workrange,
        Tab_s_input_table,
        Tab_s_trans1_const_design,
        Tab_s_trans1_const_proc,
        Tab_s_trans1_opconds_proc,
        Tab_s_trans1_temperature,
        Tab_s_trans1_electronic_damping
    }
}

MENU Tab_s_pv_type
{
    LABEL   [MC_Tab_pv_type];
    HELP    [page_trd_setting_src_help];
    ITEMS
    {
        trans1_primary_value_type (READ_ONLY)
    }
}

MENU Tab_s_trans1_input_meassurelimit
{
    LABEL   [menu_input_measrange];
    ITEMS
    {
        trans1_sensor_unit,
        trans1_sensor_low_limit,    
        trans1_sensor_high_limit
    }
}

MENU Tab_s_trans1_input_meassurerange
{
    LABEL        [menu_input_meassurerange];
    ITEMS
    {
        trans1_secondary_value_1_unit,
        trans1_scale_in_lower_value,    
        trans1_scale_in_upper_value
    }
}

MENU Tab_s_trans1_input_workrange
{
    LABEL        [menu_input_workrange];
    ITEMS
    {
        trans1_primary_value_unit,
        trans1_scale_out_lower_value,
        trans1_scale_out_upper_value
    }
}

MENU Tab_s_input_table
{
    LABEL        [menu_input_table];
    ITEMS
    {
        trans1_lin_type,
        trans1_low_press_cut_off,
        trans1_low_flow_cut_off,
        trans1_flow_lin_sqrt_point
    }
}

MENU Tab_s_trans1_const_design
{
    LABEL    [menu_const_design];
    ITEMS
    {
        Tab_s_trans1_const_design_sensor
    }
}

MENU Tab_s_trans1_const_design_sensor
{
    LABEL    [menu_const_design_sensor];
    ITEMS
    {
        trans1_sens_fill_fluid,
        trans1_diaphragm_mat,
        trans1_sensor_o_ring_mat
    }
}

MENU Tab_s_trans1_const_proc
{
    LABEL        [menu_const_proc];
    ITEMS
    {
        trans1_proc_conn_type,
        trans1_proc_conn_mat
    }
}

MENU Tab_s_trans1_opconds_proc
{
    LABEL        [menu_opcond_proc];
    ITEMS
    {
        trans1_sensor_max_static_pres
    }
}

MENU Tab_s_trans1_temperature
{
    LABEL        [trans_pres_sensor_temp_value];
    ITEMS
    {
        trans1_temperature_unit
    }
}

MENU Tab_s_trans1_electronic_damping
{
    LABEL        "Electronic Damping";
    ITEMS
    {
        trans1_electronic_damping
    }
}

/******************************************************************************/
/*****    Table: Maintenance    ***********************************************/
/******************************************************************************/
MENU Table_Main_Maintenance
{
    LABEL    [MC_Table_Main_Maintenance];
    ITEMS
    {
        Tab_m_info,
        Tab_m_trd,
        Tab_m_ai,    /* file AI1_Blk1.inc  */
        Tab_m_lcd
    }
}

MENU Tab_m_info
{
    LABEL    [MC_Tab_info];
    ITEMS
    {
        Tab_m_manuf_info,       /* file Phys_Blk.inc */
        Tab_m_block_tag,
        Tab_m_get_info,         /* file Phys_Blk.inc */
        Tab_serial_numbers,     /* file Phys_Blk.inc */
        Tab_device_revisions,   /* file Phys_Blk.inc */
        Tab_m_certificates      /* file Phys_Blk.inc */
    }
}

MENU Tab_m_block_tag
{
    LABEL    [MC_Tab_block_tag];
    ITEMS
    {
        phys_tag_desc  (READ_ONLY),
        trans1_tag_desc  (READ_ONLY),
        func1_AI_tag_desc  (READ_ONLY)
    }
}

MENU Tab_m_trd
{
    LABEL     [trans1];
    ITEMS
    {
        trans1_st_rev,
        Tab_m_pv_type,
        Tab_m_trans1_input_meassurelimit,
        Tab_m_trans1_input_meassurerange,
        Tab_m_trans1_input_workrange,
        Tab_m_input_table,
        Tab_m_trans1_const_design,
        Tab_m_trans1_const_proc,
        Tab_m_trans1_opconds_proc,
        Tab_m_trans1_temperature,
        Tab_m_trans1_electronic_damping
    }
}

MENU Tab_m_pv_type
{
    LABEL   [MC_Tab_pv_type];
    HELP    [page_trd_setting_src_help];
    ITEMS
    {
        trans1_primary_value_type  (READ_ONLY)
    }
}

MENU Tab_m_trans1_input_meassurelimit
{
    LABEL   [menu_input_measrange];
    ITEMS
    {
        trans1_sensor_unit  (READ_ONLY),
        trans1_sensor_low_limit,    
        trans1_sensor_high_limit
    }
}

MENU Tab_m_trans1_input_meassurerange
{
    LABEL   [menu_input_meassurerange];
    ITEMS
    {
        trans1_secondary_value_1_unit  (READ_ONLY),
        trans1_scale_in_lower_value  (READ_ONLY),    
        trans1_scale_in_upper_value  (READ_ONLY)
    }
}

MENU Tab_m_trans1_input_workrange
{
    LABEL   [menu_input_workrange];
    ITEMS
    {
        trans1_primary_value_unit  (READ_ONLY),
        trans1_scale_out_lower_value  (READ_ONLY),
        trans1_scale_out_upper_value  (READ_ONLY)
    }
}

MENU Tab_m_input_table
{
    LABEL   [menu_input_table];
    ITEMS
    {
        trans1_lin_type  (READ_ONLY),
        trans1_low_flow_cut_off  (READ_ONLY),
        trans1_flow_lin_sqrt_point  (READ_ONLY)
    }
}

MENU Tab_m_trans1_const_design
{
    LABEL   [menu_const_design];
    ITEMS
    {
        Tab_m_trans1_const_design_sensor
    }
}

MENU Tab_m_trans1_const_design_sensor
{
    LABEL   [menu_const_design_sensor];
    ITEMS
    {
        trans1_sens_fill_fluid  (READ_ONLY),
        trans1_diaphragm_mat  (READ_ONLY),
        trans1_sensor_o_ring_mat  (READ_ONLY)
    }
}

MENU Tab_m_trans1_const_proc
{
    LABEL   [menu_const_proc];
    ITEMS
    {
        trans1_proc_conn_type  (READ_ONLY),
        trans1_proc_conn_mat  (READ_ONLY)
    }
}

MENU Tab_m_trans1_opconds_proc
{
    LABEL   [menu_opcond_proc];
    ITEMS
    {
        trans1_sensor_max_static_pres
    }
}

MENU Tab_m_trans1_temperature
{
    LABEL   [trans_pres_sensor_temp_value];
    ITEMS
    {
        trans1_temperature_unit  (READ_ONLY)
    }
}

MENU Tab_m_trans1_electronic_damping
{
    LABEL        "Electronic Damping";
    ITEMS
    {
        trans1_electronic_damping  (READ_ONLY)
    }
}









METHOD std_NodeAddress
{
    LABEL        [menu_Device_NodeAddress];
    DEFINITION
    {
    }
}

METHOD std_LoadinDevice
{
    LABEL        [menu_Device_LoadinDevice];
    DEFINITION
    {
    }
}

METHOD std_LoadinPC
{
    LABEL        [menu_Device_LoadinPC];
    DEFINITION
    {
    }
}

METHOD std_Funktionsleiste
{
    LABEL        [menu_View_Toolbar];
    DEFINITION
    {
    }
}

METHOD std_Statuszeile
{
    LABEL        [menu_View_Statusbar];
    DEFINITION
    {
    }
}

METHOD std_Update
{
    LABEL        [menu_View_Update];
    DEFINITION
    {
    }
}

METHOD method_set
{
    LABEL        [transfer];
    HELP         [transfer_help];
    DEFINITION
    {
    }
}

METHOD  method_pre_write_phys_write_locking
{
    LABEL   [method_pre_write_phys_write_locking];
    DEFINITION
    {
        int ret;
        ReadCommand (read_phys_write_locking);
        if ( phys_write_locking == 0 )
        {
            ret = ACKNOWLEDGE([label_DeviceIsWriteProtected]);
            if (ret) process_abort();
        }
    }
}

METHOD method_write_lin_type
{
    LABEL [MC_Write];
    DEFINITION
    {
        WriteCommand(write_trans1_lin_type);
        WriteCommand(write_trans1_low_press_cut_off);
        ReadCommand(read_trans1_lin_type);
        ReadCommand(read_trans1_low_press_cut_off);
    }
}

METHOD method_write_scale_in
{
    LABEL [MC_Write];
    DEFINITION
    {
        WriteCommand(write_trans1_scale_in);
        ReadCommand(read_trans1_scale_in);
    }
}

METHOD method_write_secondary_value_1_unit
{
    LABEL [MC_Write];
    DEFINITION
    {
        WriteCommand(write_trans1_scale_in);
        WriteCommand(write_trans1_secondary_value_1_unit);
        ReadCommand(read_trans1_secondary_value_1_unit);
        ReadCommand(read_trans1_scale_in);
    }
}

METHOD method_write_scale_out
{
    LABEL [MC_Write];
    DEFINITION
    {
        WriteCommand(write_trans1_scale_out);
        ReadCommand(read_trans1_scale_out);
    }
}

METHOD method_write_trans1_primary_value_unit
{
    LABEL [MC_Write];
    DEFINITION
    {
        WriteCommand(write_trans1_scale_out);
        WriteCommand(write_trans1_primary_value_unit);
        ReadCommand(read_trans1_primary_value_unit);
        ReadCommand(read_trans1_scale_out);
    }
}

METHOD method_write_temperature_unit
{
    LABEL [MC_Write];
    DEFINITION
    {
        WriteCommand(write_trans1_temperature_unit);
        ReadCommand(read_trans1_temperature_unit);
    }
}

METHOD method_set_cal_point_lo
{
    LABEL        [MC_Start];
    DEFINITION
    {
        int ret,fValue;

        if (func1_AI_simulation_enabled == 0)        //0 = [off]
        {
            ret = GET_DEV_VAR_VALUE("Enter applied pressure value", trans1_cal_point_lo);
            fValue = trans1_cal_point_lo;

            if (ret < 0)
            {
                process_abort();
            }

            WriteCommand (write_trans1_cal_point_lo);
            ReadCommand (read_trans1_cal_point_lo);
//            if ( fValue == write_trans1_cal_point_lo )
//            {
//                ACKNOWLEDGE("Sensor trim succeeded");  
//            } 
//            else
//            {
//                ACKNOWLEDGE("Sensor trim failed");  
//                process_abort();
//            }
        }
        else
        {
            ACKNOWLEDGE("Function not permitted during simulation");  
        }

    }
}

METHOD method_set_cal_point_hi
{
    LABEL        [MC_Start];
    DEFINITION
    {
        int ret,fValue;

        //ReadCommand(func1_AI_simulation_enabled);
        if (func1_AI_simulation_enabled == 0)        //0 = [off]
        {
            ret = GET_DEV_VAR_VALUE("Enter applied pressure value", trans1_cal_point_hi);
            fValue = trans1_cal_point_hi;

            if (ret < 0)
            {
                process_abort();
            }

            WriteCommand (write_trans1_cal_point_hi);
            ReadCommand (read_trans1_cal_point_hi);
//            if (fValue == trans1_cal_point_hi)
//            {
//                ACKNOWLEDGE("Sensor trim succeeded");  
//            }
//            else
//            {
//                ACKNOWLEDGE("Sensor trim failed");  
//                process_abort();
//            }
        }
        else
        {
            ACKNOWLEDGE("Function not permitted during simulation");  
        }

    }
}

METHOD method_set_trans1_zero_adjustment
{
    LABEL   [MC_Start];
    CLASS INPUT;
    DEFINITION
    {
        int status;

        if (func1_AI_simulation_enabled == 0)        //0 = [off]
        {
            trans1_zero_adjustment = 1;
            
            status = WriteCommand (write_trans1_zero_adjustment);

            if ( status >= ID_FC_ERROR )
            {
                //ACKNOWLEDGE([acknowledge_process_aborted]);
                process_abort();
            } 
            else
            {
                ACKNOWLEDGE("Zero adjustment succeeded");  
            } 
        }
        else
        {
            ACKNOWLEDGE([function_not_during_simu]);  
        }
    }
}

METHOD reset_pressure_pointer
{
    LABEL    [reset]; 
    HELP    [reset_pres_pointer_Help];
    DEFINITION
    {
        int status;
        int choice_mode, choise_reset;

        choice_mode= SELECT_FROM_LIST([select_to_reset], [maxmin_R]);
        choise_reset = SELECT_FROM_LIST ([ack_reset], [no_yes]);

        switch (choise_reset)                          
        {                                        
            case 0:                              
                    ACKNOWLEDGE([acknowledge_process_aborted]);
            break;                               
            case 1:                               
            switch (choice_mode)
            {
                case 0: 
                    status = WriteCommand(write_trans1_max_sensor_value);
                    if ( status >= ID_FC_ERROR )
                    {
                        ACKNOWLEDGE([acknowledge_process_aborted]);
                        process_abort();
                    }
                    else
                        ACKNOWLEDGE([acknowledge_pointer_max_reset]);  

                break;
                case 1:
                    status = WriteCommand(write_trans1_min_sensor_value);
                    if ( status >= ID_FC_ERROR )
                    {
                        ACKNOWLEDGE([acknowledge_process_aborted]);
                        process_abort();
                    }
                    else
                        ACKNOWLEDGE([acknowledge_pointer_min_reset]);  
                break;
                case 2:
                    status = WriteCommand(write_trans1_max_sensor_value);
                    if ( status >= ID_FC_ERROR )
                    {
                        ACKNOWLEDGE([acknowledge_process_aborted]);
                        process_abort();
                    }
                    else
                    {
                        status = WriteCommand(write_trans1_min_sensor_value);
                        if ( status >= ID_FC_ERROR )
                        {
                            ACKNOWLEDGE([acknowledge_process_aborted]);
                            process_abort();
                        }
                        else
                            ACKNOWLEDGE([acknowledge_pointer_max_min_reset]);  
                    }
                break;
            }//switch (choice_mode)
            break;
        }
    }
} 

METHOD reset_temperatur_pointer
{
    LABEL    [reset]; 
    HELP    [reset_temp_sens_pointer_Help];
    DEFINITION
    {
        int status;
        int choice_mode, choise_reset;

        choice_mode= SELECT_FROM_LIST([select_to_reset], [maxmin_R]);
        choise_reset = SELECT_FROM_LIST ([ack_reset], [no_yes]);

        switch (choise_reset)                          
        {                                        
            case 0:                              
                    ACKNOWLEDGE([acknowledge_process_aborted]);
            break;                               
            case 1:                               
            switch (choice_mode)
            {
                case 0: 
                    status = WriteCommand(write_trans1_max_temperature);
                    if ( status >= ID_FC_ERROR )
                    {
                        ACKNOWLEDGE([acknowledge_process_aborted]);
                        process_abort();
                    }
                    else
                        ACKNOWLEDGE([acknowledge_pointer_max_reset]);  

                break;
                case 1:
                    status = WriteCommand(write_trans1_min_temperature);
                    if ( status >= ID_FC_ERROR )
                    {
                        ACKNOWLEDGE([acknowledge_process_aborted]);
                        process_abort();
                    }
                    else
                        ACKNOWLEDGE([acknowledge_pointer_min_reset]);  
                break;
                case 2:
                    status = WriteCommand(write_trans1_max_temperature);
                    if ( status >= ID_FC_ERROR )
                    {
                        ACKNOWLEDGE([acknowledge_process_aborted]);
                        process_abort();
                    }
                    else
                    {
                        status = WriteCommand(write_trans1_min_temperature);
                        if ( status >= ID_FC_ERROR )
                        {
                            ACKNOWLEDGE([acknowledge_process_aborted]);
                            process_abort();
                        }
                        else
                            ACKNOWLEDGE([acknowledge_pointer_max_min_reset]);  
                    }
                break;
            }//switch (choice_mode)
            break;
        }
    } 
} 
